summaryrefslogtreecommitdiffstats
path: root/kmobile/kmobile.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmobile/kmobile.cpp')
-rw-r--r--kmobile/kmobile.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kmobile/kmobile.cpp b/kmobile/kmobile.cpp
index 48d8d298..3d867b3d 100644
--- a/kmobile/kmobile.cpp
+++ b/kmobile/kmobile.cpp
@@ -53,13 +53,13 @@
#include "kmobile_selectiondialog.h"
KMobile::KMobile()
- : KMainWindow( 0, "kmobile" )
+ : TDEMainWindow( 0, "kmobile" )
{
m_config = new TDEConfig("kmobilerc");
m_view = new KMobileView(this, m_config);
// tell the KMainWindow that this is indeed the main widget
setCentralWidget(m_view);
// then, setup our actions
@@ -104,13 +104,13 @@ void KMobile::setupActions()
KStdAction::configureToolbars(TQT_TQOBJECT(this), TQT_SLOT(optionsConfigureToolbars()), actionCollection());
KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(optionsPreferences()), actionCollection());
- new KAction(i18n("&Add Device..."), "folder_new", 0,
+ new TDEAction(i18n("&Add Device..."), "folder_new", 0,
TQT_TQOBJECT(this), TQT_SLOT(addDevice()), actionCollection(), "device_add");
- new KAction( KGuiItem( i18n("&Remove Device"), "edittrash", i18n("Remove this device") ),
+ new TDEAction( KGuiItem( i18n("&Remove Device"), "edittrash", i18n("Remove this device") ),
"Delete", TQT_TQOBJECT(this), TQT_SLOT(removeDevice()), actionCollection(), "device_remove");
- new KAction(i18n("Re&name Device..."), 0, Key_F2,
+ new TDEAction(i18n("Re&name Device..."), 0, Key_F2,
TQT_TQOBJECT(this), TQT_SLOT(renameDevice()), actionCollection(), "device_rename");
- new KAction(i18n("&Configure Device..."), "configure", 0,
+ new TDEAction(i18n("&Configure Device..."), "configure", 0,
TQT_TQOBJECT(this), TQT_SLOT(configDevice()), actionCollection(), "device_configure");
createGUI();
@@ -53,13 +53,13 @@
m_config = new TDEConfig("kmobilerc");
m_view = new KMobileView(this, m_config);
- // tell the KMainWindow that this is indeed the main widget
+ // tell the TDEMainWindow that this is indeed the main widget
setCentralWidget(m_view);
// then, setup our actions